#!/bin/bash

################################################################################
# Constantes de base

# definition, si ce n'est pas une variable d'environnement, du time-out
if [ -z "$MAXTIME" ] ; then
	MAXTIME="30" 
fi

# if [ -z "$PROCESSOR" ] ; then
# 	MAXTIME="C1" 
# fi

################################################################################
# Decoder la ligne de commandes

if [ "$1" = "-help" ] ; then
	echo "usage "`basename $0`" [-help]"
	echo "      "`basename $0`" disk-image command-to-operate [-tool toolname] [-test testname]"
	exit
elif [ $# -lt 2 ] ; then
	echo "bad invocation, please run '"`basename $0`" -help' for documentation"
	exit
fi
VMPATH="$1"
COMMAND="$2"
shift 2
if [ "$1" = "-tool" ] ; then
	THE_TOOL_NAME=$2
	shift 2
else
	THE_TOOL_NAME="no_tool"
fi
if [ "$1" = "-test" ] ; then
	THE_TEST_NAME=$2
	shift 2
else
	THE_TEST_NAME="test_with_no_name"
fi

if [ -z "$RUN_IDENTIFIER" ] ; then
	RUN_IDENTIFIER="run-id"
fi

if [ -f "/tmp/count_run.$NODE_NUMBER" ] ; then
	X=`cat /tmp/count_run.$NODE_NUMBER`
	X=`expr $X + 1`
	echo $X > "/tmp/count_run.$NODE_NUMBER"
else
	echo 1 > "/tmp/count_run.$NODE_NUMBER"
fi


################################################################################
# Parametrages divers

if [ -z "$A_F_RADIX" ] ; then
	LOG_FILE="$OUTPUT_DIR/node_${NODE_NUMBER}_CSV/run-${THE_TOOL_NAME}-${THE_TEST_NAME}-${RUN_IDENTIFIER}.csv"
else
	LOG_FILE="$OUTPUT_DIR/node_${NODE_NUMBER}_CSV/run-${A_F_RADIX}-${THE_TOOL_NAME}-${THE_TEST_NAME}-${RUN_IDENTIFIER}.csv"
fi

if [ -z "$SUM_FILE" ] ; then
	SUM_FILE="/data1/CSV/summary-${THE_TOOL_NAME}.csv"	
fi # sinon elle este xportee par l'appelant

STDERR_FILE="$OUTPUT_DIR/node_${NODE_NUMBER}_OUTPUTS/log-${THE_TOOL_NAME}-${THE_TEST_NAME}-${RUN_IDENTIFIER}.stderr"

################################################################################
# Au travail!!!

# demarrer la VM
sh vm.sh $VMPATH 2> /dev/null
# lancer le monitoring
MONITOR=/tmp/$$.pid
touch $MONITOR
#--normalise
python monitor.py --tries 10 --top-regexp top.re --timeout $MAXTIME --log $LOG_FILE --summary $SUM_FILE --priv "$BENCHKIT_DIR/bk-private_key" --pidfile $MONITOR root@localhost:2222 "$THE_TOOL_NAME,$THE_TEST_NAME,$AN_EXAMINATION,{MEM},{CPU},{TIME},{STATUS},$RUN_IDENTIFIER" 2>> "$STDERR_FILE"

ERRNO="$?"

if [ "$ERRNO" -gt 0 ] ; then
	echo >> "$STDERR_FILE"
	echo "Monitor could not connect -- error $ERRNO ($THE_TOOL_NAME, $THE_TEST_NAME, $RUN_IDENTIFIER)" >> "$STDERR_FILE"
	echo >> "$STDERR_FILE"
else
	ssh -i "$BENCHKIT_DIR/bk-private_key" -p 2222 $VM_LOGIN@localhost 'echo coucou > /tmp/toto' & 
	sleep 1
	ssh -i "$BENCHKIT_DIR/bk-private_key" -p 2222 $VM_LOGIN@localhost "$COMMAND" 2>> "$STDERR_FILE"
fi
#on arrete tout
python stopall.py --priv "$BENCHKIT_DIR/bk-private_key" $MONITOR root@localhost:2222 2> /dev/null
rm -f $MONITOR
