
if [ "$1" = "-help" -o "$1" = "--help" ] ; then
	echo "usage: "`basename $0`" [-deploy] [-effective]"
	echo "      -deploy:    enforces the deployment of all scripts on the target machines"
	echo "                  and checks for the existence of image  files for the  VMs."
	echo "      -effective: requested to execute the files on the remote nodes, otherwise"
	echo "                  only the files to be executed are generated (for checks)"
	exit
fi

source ./configuration.sh

if [ "$1" = "-deploy" ] ; then
	PROBLEM=""
	echo
	echo "==============================================================="
	echo " Deploying BenchKit on the target machines"
	echo "==============================================================="
	echo
	VM_LIST=`grep -v ^# tool_list.txt | grep -v ^$ | cut -d ':' -f 3 | sort -u`
	PHYS_MACHINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_REMOTE_NODES" | cut -d ':' -f 2,3 | sort -u`
	for pm in $PHYS_MACHINE ; do
		for vm in $VM_LIST ; do
			HOST=`echo $pm | cut -d ':' -f 1`
			LOGIN=`echo $pm | cut -d ':' -f 2`
			echo "checking $VM_DIRECTORY/$vm on $LOGIN@$HOST"
			LINE=`ssh $LOGIN@$HOST "ls $VM_DIRECTORY/$vm" 2>/tmp/exec.$$`
			if [ "$LINE" = "$VM_DIRECTORY/$vm" ] ; then
				echo "      OK"
			else
				echo "      It says: "`cat /tmp/exec.$$`
				PROBLEM="$PROBLEM#file $VM_DIRECTORY/$vm is not deployed on $LOGIN@$HOST"
			fi
		done
	done
	echo 
	echo "deploying BenchKit files on the physical machines"
	echo 
	for pm in $PHYS_MACHINE ; do
		HOST=`echo $pm | cut -d ':' -f 1`
		LOGIN=`echo $pm | cut -d ':' -f 2`
		echo "   deploying on $LOGIN@$HOST"
		ssh $LOGIN@$HOST "if [ ! -d \"$BENCHKIT_DIR\" ] ; then mkdir \"$BENCHKIT_DIR\" ; fi " 2>/tmp/exec.$$
		LINE=`cat /tmp/exec.$$`
		if [ "$LINE" ] ; then
			PROBLEM="$PROBLEM#cannot create directory $LOGIN$HOST:$BENCHKIT_DIR"
		fi
		scp bk-private_key halt_a_vm.sh top.re launch_a_command.sh launch_a_run.sh launch_a_vm.sh launch_benchmark.sh vm.sh monitor.py stopall.py rmachine_list.txt input_list.txt tool_list.txt invocation_template.txt monitor-supp.tgz $LOGIN@$HOST:$BENCHKIT_DIR
		ssh $LOGIN@$HOST "cd $BENCHKIT_DIR ; tar xzf monitor-supp.tgz ; rm -f monitor-supp.tgz"
	done
	echo
	if [ "$PROBLEM" ] ; then
		echo "======================================"
		echo "The following problems were reported:"
		echo $PROBLEM | tr '#' '\n'
		echo
		echo "Deployment of benchkit unsuccessful, no execution is launched"
		exit
	else
		echo "Deployment OK, no problem was reported"
	fi
	exit
fi

#!/bin/bash


TOOLS=`grep -v ^# tool_list.txt | grep -v ^$ | cut -d ':' -f 1,2,3`

MAX_NODE=`grep ^NB_REMOTE_NODES $REMOTE_MACHINES_LIST_FILE | cut -d ':' -f 2`

BASE_EXECUTION_SCRIPT="BenchKit_node_"

# peut-etre remplace par une liste de modeles en dur...
TESTS=`grep -v ^# "$TEST_LIST_FILE" | grep -v ^$ ` 

# supprimer les fichiers de resultats precedents
CPT=1
while [ "$CPT" -le "$MAX_NODE" ] ; do
	echo > $BASE_EXECUTION_SCRIPT$CPT.sh 
	LINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_REMOTE_NODES" | grep "^$CPT:"`
	HOST=`echo $LINE | cut -d ':' -f 2`
	echo 'if [ -d "'$OUTPUT_DIR'" ] ; then' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   if [ -d "'$OUTPUT_DIR'/node_'$CPT'_CSV" ] ; then' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      rm -rf "'$OUTPUT_DIR'/node_'$CPT'_CSV/"*' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   else' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      mkdir "'$OUTPUT_DIR'/node_'$CPT'_CSV"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   fi' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   if [ -d "'$OUTPUT_DIR'/node_'$CPT'_OUTPUTS" ] ; then' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      rm -rf "'$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/"*' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   else' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      mkdir "'$OUTPUT_DIR'/node_'$CPT'_OUTPUTS"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   fi' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   if [ -d "'$OUTPUT_DIR'/node_'$CPT'_CONFIGURATIONS" ] ; then' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      rm -rf "'$OUTPUT_DIR'/node_'$CPT'_CONFIGURATIONS/"*' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   else' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '      mkdir "'$OUTPUT_DIR'/node_'$CPT'_CONFIGURATIONS"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   fi' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'else' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   mkdir "'$OUTPUT_DIR'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   mkdir "'$OUTPUT_DIR'/node_'$CPT'_CSV"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   mkdir "'$OUTPUT_DIR'/node_'$CPT'_OUTPUTS"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo '   mkdir "'$OUTPUT_DIR'/node_'$CPT'_CONFIGURATIONS"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'fi' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'rm -f /tmp/count_run.'$CPT >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export MAXTIME="'$TIME_CONFINMENT'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export MAXMEM="'$MEM_CONFINMENT'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export BENCHKIT_DIR="'$BENCHKIT_DIR'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export OUTPUT_DIR="'$OUTPUT_DIR'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export VM_DIRECTORY="'$VM_DIRECTORY'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export NODE_NUMBER="'$CPT'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export BENCHKIT_VERSION="'$BENCHKIT_VERSION'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'export VM_LOGIN="'$VM_LOGIN'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	CPT=`expr $CPT + 1`
done

# lancer les jobs en repartissant sur toutes les machines disponibles

GCPT=1 # for unique run identifiers
CPT=1
# generation de l'espace d'etats
for T in $TOOLS ; do
	LINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_REMOTE_NODES" | grep "^$CPT:"`
	HOST=`echo $LINE | cut -d ':' -f 2`
	EXAM=`echo $T | cut -d ':' -f 1`
	VM=`echo $T | cut -d ':' -f 3`
	TN=`echo $T | cut -d ':' -f 2`
	for M in $TESTS ; do
		runID=`date +%s``perl -e "printf '%5d', $GCPT" | tr ' ' 0`'_n_'$CPT
		echo >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo "### launching examination $EXAM on virtual machine $VM (too $TN) for test $M ###" >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'export RUN_IDENTIFIER="'$runID'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh 
		echo 'export AN_EXAMINATION="'$EXAM'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'export TOOL_NAME="'$TN'"' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'echo > '$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/'$runID'.output' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'echo "execution on node '$CPT': "`uname -n`" (runId='$runID')" >> '$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/'$runID'.output' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'echo "=====================================================================" >> '$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/'$runID'.output' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'sh launch_a_run.sh '$VM_DIRECTORY'/'$VM' '$M' >> '$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/'$runID'.output' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		if [ "$EMAIL_RUN_REPORT" ] ; then
			echo 'cat '$OUTPUT_DIR'/node_'$CPT'_OUTPUTS/'$runID'.output | mail -s "node '$CPT': end of '$EXAM' on '$M' for '$TN' (BenchKit v-'$BENCHKIT_VERSION')" '$EMAIL_RUN_REPORT >> $BASE_EXECUTION_SCRIPT$CPT.sh
		fi
		CPT=`expr $CPT + 1`
		GCPT=`expr $GCPT + 1`
		if [ "$CPT" -gt "$MAX_NODE" ] ; then
			CPT=1
		fi
	done
done

# envoyer les fichiers de resultats apres execution
CPT=1
while [ "$CPT" -le "$MAX_NODE" ] ; do
	LINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_REMOTE_NODES" | grep "^$CPT:"`
	HOST=`echo $LINE | cut -d ':' -f 2`
	echo >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	echo 'cd '$OUTPUT_DIR >> $BASE_EXECUTION_SCRIPT$CPT.sh
	if [ "$EMAIL_GLOBAL_REPORT" ] ; then
		echo 'tar czfv archive_node_'$CPT'.tgz node_'$CPT'_CSV node_'$CPT'_OUTPUTS node_'$CPT'_CONFIGURATIONS' >> $BASE_EXECUTION_SCRIPT$CPT.sh
		echo 'uuencode archive_node_'$CPT'.tgz archive_node_'$CPT'.tgz | mail -s "node '$CPT': global results from BenchKit v-'$BENCHKIT_VERSION'" '$EMAIL_GLOBAL_REPORT >> $BASE_EXECUTION_SCRIPT$CPT.sh 
		echo 'cat /tmp/count_run.'$CPT' | mail -s "node '$CPT': `cat /tmp/count_run.'$CPT'` runs terminated" '$EMAIL_GLOBAL_REPORT >> $BASE_EXECUTION_SCRIPT$CPT.sh 
	fi 
	CPT=`expr $CPT + 1`
done

if [ "$1" = "-effective" ] ; then
	
	LINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_MACHINES" | grep "^1:"`
	HOST=`echo $LINE | cut -d ':' -f 2`
	LOGIN=`echo $LINE | cut -d ':' -f 3`
	# copier les fichiers d'execution sur les machines cibles
	scp  ${BASE_EXECUTION_SCRIPT}* $LOGIN@$HOST:$BENCHKIT_DIR

	# Lancer les excutions en parallele
	CPT=1
	while [ "$CPT" -le "$MAX_NODE" ] ; do
		LINE=`grep -v ^# "$REMOTE_MACHINES_LIST_FILE" | grep -v "^NB_MACHINES" | grep "^$CPT:"`
		HOST=`echo $LINE | cut -d ':' -f 2`
		LOGIN=`echo $LINE | cut -d ':' -f 3`
		echo "Starting execution on $HOST"
		ssh $LOGIN@$HOST "cd $BENCHKIT_DIR ; nohup sh $BASE_EXECUTION_SCRIPT$CPT.sh > /dev/null 2> /dev/null & " &
		CPT=`expr $CPT + 1`
	done
else
	echo "Generated files but real execution requires option '-effective'"
fi
