import sys, os, time, signal, argparse, re

parser = argparse.ArgumentParser(description="Stops VM and its monitor.")
parser.add_argument("--priv", metavar="PRIV", type=str,
                    dest="priv", default="mcc.priv",
                    help="load private key from file PRIV (default 'mcc.priv')")
parser.add_argument("--verbose", action="store_true",
                    dest="verbose", default=False,
                    help="display messages about things in progress")
parser.add_argument("--qemu", metavar="PORT", type=int,
                    dest="qemu", default=None,
                    help="port for qemu monitor")
parser.add_argument("pid", metavar="PIDFILE", type=str,
                    default="monitor.pid",
                    help="file where PID of monitor process is stored")
parser.add_argument("login", metavar="USER@HOST:PORT", type=str,
                    help="parameters for SSH connection")

args = parser.parse_args()

match = re.match("^(?P<username>[^@]+)@(?P<hostname>[^:]+):(?P<port>[0-9]+)$",
                 args.login)
if match is None :
    parser.print_help()
    sys.exit(1)

login = match.groupdict()

try :
    pid = int(open(args.pid).readline())
    if args.verbose :
        print "sending SIGTERM to monitor"
    os.kill(pid, signal.SIGTERM)
except :
    pass

time.sleep(1)
try :
    if args.verbose :
        print "halting VM through SSH"
    os.system("ssh -i %s -p %s %s@%s 'halt; sleep 5'"
              % (args.priv, login["port"],
                 login["username"], login["hostname"]))
except :
    pass

time.sleep(2)
try :
    if args.verbose :
        print "sending SIGKILL to monitor"
    os.kill(args.pid, signal.SIGKILL)
except :
    pass

time.sleep(3)
try :
    if args.qemu :
        if args.verbose :
            print "halting VM through QEMU monitor"
        os.system("echo quit | nc localhost %s" % args.qemu)
except :
    pass

